@@ -252,6 +252,9 @@ slop::SlopOptions* getSlopOptions( cxxopts::Options& options ) {
     if ( options.count( "highlight" ) > 0 ) {
         foo->highlight = options["highlight"].as<bool>();
     }
+    if ( options.count( "nodrag" ) > 0 ) {
+        foo->nodrag = options["nodrag"].as<bool>();
+    }
     if ( options.count( "nodecorations" ) > 0 ) {
         foo->nodecorations = options["nodecorations"].as<int>();
         if ( foo->nodecorations < 0 || foo->nodecorations > 2 ) {
@@ -293,7 +296,7 @@ OPTIONS
 
        -g, --geometry=GEOMETRY
               Sets the region to capture, uses local coordinates from the  given
-              window. So -g10x30-5+0 would represent the rectangle wxh+x+y where
+              window. So -g 10x30-5+0 would represent the rectangle wxh+x+y where
               w=10, h=30, x=-5, and y=0. x and y are the upper left location  of
               this rectangle.
 
@@ -343,6 +346,10 @@ SLOP OPTIONS
               this to 0 will disable window selections. Alternatively setting it
               to 9999999 would force a window selection.
 
+
+       -D, --nodrag
+              Select region with two clicks instead of click and drag
+
        -c, --color=FLOAT,FLOAT,FLOAT,FLOAT
               Sets  the selection rectangle's color. Supports RGB or RGBA input.
               Depending on the system's window manager/OpenGL support, the opac‐
@@ -413,6 +420,7 @@ int app( int argc, char** argv ) {
     ("b,bordersize", "Sets the selection rectangle's thickness.", cxxopts::value<float>())
     ("p,padding", "Sets the padding size for the selection, this can be negative.", cxxopts::value<float>())
     ("t,tolerance", "How far in pixels the mouse can move after clicking, and still be detected as a normal click instead of a click-and-drag. Setting this to 0 will disable window selections. Alternatively setting it to 9999999 would force a window selection.", cxxopts::value<float>())
+    ("D,nodrag", "Select region with two clicks instead of click and drag")
     ("c,color", "Sets  the  selection  rectangle's  color.  Supports  RGB or RGBA input. Depending on the system's window manager/OpenGL  support, the opacity may be ignored.", cxxopts::value<std::string>())
     ("r,shader", "This  sets  the  vertex shader, and fragment shader combo to use when drawing the final framebuffer to the screen. This obviously only  works  when OpenGL is enabled. The shaders are loaded from ~/.config/maim. See https://github.com/naelstrof/slop for more information on how to create your own shaders.", cxxopts::value<std::string>())
     ("n,nodecorations", "Sets the level of aggressiveness when trying to remove window decroations. `0' is off, `1' will try lightly to remove decorations, and `2' will recursively descend into the root tree until it gets the deepest available visible child under the mouse. Defaults to `0'.", cxxopts::value<int>()->implicit_value("1"))
@@ -445,7 +453,8 @@ int app( int argc, char** argv ) {
 
     // Check if output is a tty before dumping binary data to it
     if ( isatty( fileno( stdout ) ) && !maimOptions->savepathGiven ) {
-        std::cout << HELP_MESSAGE << std::endl;
+        std::cout << "Please provide an output path or redirect stdout to a file." << std::endl;
+        std::cout << "Run maim --help for more information." << std::endl;
         return 0;
     }
 
